@@ -2,10 +2,10 @@ from pathlib import Path
 
 import click
 
+from indico_install.cluster_manager import ClusterManager
 from indico_install.kube.svc.restart import restart
 from indico_install.setup import configure_gcr_key
 from indico_install.utils import options_wrapper, run_cmd
-from indico_install.cluster_manager import ClusterManager
 
 
 def find_dependent_services(updated_services: list) -> set:
@@ -26,7 +26,8 @@ def find_dependent_services(updated_services: list) -> set:
         for idx, ups in enumerate(updated_services)
         if any(ups.startswith(svc_type) for svc_type in svc_types_to_check)
     }
-    # We bank on the fact that names of deployments, statefulsets, configs, secrets are all unique
+    # We bank on the fact that names of deployments,
+    # statefulsets, configs, secrets are all unique
 
     dependency_info = []
     dependent_services = set([])
@@ -57,7 +58,7 @@ def find_dependent_services(updated_services: list) -> set:
 
 @click.command("apply")
 @click.pass_context
-@click.argument("service", required=False)
+@click.argument("services", required=False, nargs=-1)
 @click.option(
     "--restart-deps/--no-restart-deps",
     default=True,
@@ -68,7 +69,7 @@ def find_dependent_services(updated_services: list) -> set:
 def apply(
     ctx,
     restart_deps=True,
-    service=None,
+    services=None,
     deployment_root=None,
     yes=False,
     cluster_manager=None,
@@ -90,28 +91,33 @@ def apply(
     # These are services that were actually modified
     updated_services = []
 
-    if service is not None:
-        templates = run_cmd(
-            f"ls {generated_dir} | grep '{service}'", silent=True
-        ).splitlines()
-        for t in templates:
-            results = run_cmd(
-                f"kubectl apply -f {generated_dir / t} --dry-run 2>&1 | grep -v 'support dry-run'"
-            )
+    if services:
+        for service in services:
+            templates = run_cmd(
+                f"ls {generated_dir} | grep '{service}'", silent=True
+            ).splitlines()
+            for t in templates:
+                results = run_cmd(
+                    f"kubectl apply -f {generated_dir / t} --dry-run 2>&1 | "
+                    "grep -v 'support dry-run'"
+                )
 
-        if yes or click.confirm("Ready to apply these changes?"):
-            outs = [run_cmd(f"kubectl apply -f {generated_dir / t}") for t in templates]
-            updated_services.extend(
-                [
-                    line.split(" ", 1)[0]
-                    for out in outs
-                    for line in out.splitlines()
-                    if any(status in line for status in ("created", "configured"))
+            if yes or click.confirm("Ready to apply these changes?"):
+                outs = [
+                    run_cmd(f"kubectl apply -f {generated_dir / t}") for t in templates
                 ]
-            )
+                updated_services.extend(
+                    [
+                        line.split(" ", 1)[0]
+                        for out in outs
+                        for line in out.splitlines()
+                        if any(status in line for status in ("created", "configured"))
+                    ]
+                )
     else:
         results = run_cmd(
-            f"kubectl apply -R -f {generated_dir} --dry-run 2>&1 | grep -v 'support dry-run'",
+            f"kubectl apply -R -f {generated_dir} --dry-run 2>&1 "
+            "| grep -v 'support dry-run'",
             silent=True,
         )
         click.echo("\n".join(results.split(",")) + "\n")
@@ -149,9 +155,9 @@ def apply(
                     fg="yellow",
                 )
                 return
-            for dep_service in dependent_services:
-                ctx.invoke(restart, service=dep_service, contains=False, wait="2m")
+            ctx.invoke(restart, services=list(dependent_services), contains=False, wait="2m")
         else:
             click.secho(
-                f"{', '.join(updated_confs)} were updated. Make sure to restart dependent services"
+                f"{', '.join(updated_confs)} were updated. "
+                "Make sure to restart dependent services"
             )
