@@ -1,58 +1,65 @@
-import os
 import click
+
 from indico_install.config import merge_dicts
-from indico_install.utils import run_cmd
 from indico_install.infra.init import init
+from indico_install.utils import current_user, run_cmd
+
+from .cluster import cluster
 
 DEFAULT_NODE_CONFIGS = {
     "image-type": "UBUNTU",
     "disk-type": "pd-standard",
-    "scopes": '"https://www.googleapis.com/auth/devstorage.read_only","https://www.googleapis.com/auth/logging.write","https://www.googleapis.com/auth/monitoring","https://www.googleapis.com/auth/servicecontrol","https://www.googleapis.com/auth/service.management.readonly","https://www.googleapis.com/auth/trace.append"',
+    "scopes": (
+        '"https://www.googleapis.com/auth/devstorage.read_only",'
+        '"https://www.googleapis.com/auth/logging.write",'
+        '"https://www.googleapis.com/auth/monitoring",'
+        '"https://www.googleapis.com/auth/servicecontrol",'
+        '"https://www.googleapis.com/auth/service.management.readonly",'
+        '"https://www.googleapis.com/auth/trace.append"'
+    ),
     "no-enable-autorepair": None,
     "min-nodes": 0,
     "max-nodes": 3,
 }
 
 NODE_POOL_TYPES = {
-    "default-gpu-pool": {
-        "machine-type": "n1-standard-8",
-        "accelerator": "type=nvidia-tesla-p4,count=1",
-    },
     # N2s do not support GPU and are not supported in us-east4-c
-    "default-cpu-pool": {"machine-type": "c2-standard-4"},
-    "default-mem-pool": {"machine-type": "n1-standard-8"},
-    "default-pool": {"machine-type": "n1-standard-8"},
+    "default-pool": {"machine-type": "n2-standard-8"},
     "default-pvm-pool": {
-        "machine-type": "n1-standard-8",
+        "machine-type": "n2-standard-8",
         "preemptible": None,
+        "enable-autoscaling": None,
+        "max-nodes": 6,
+        "min-nodes": 0,
+    },
+    "default-gpu-pvm-pool": {
+        "machine-type": "n1-highmem-4",
+        "accelerator": "type=nvidia-tesla-t4,count=1",
+        "preemptible": None,
+        "enable-autoscaling": None,
+        "min-nodes": 0,
         "max-nodes": 6,
     },
-    "t4-gpu-pool": {
+    "default-gpu-pool": {
         "machine-type": "n1-highmem-4",
         "accelerator": "type=nvidia-tesla-t4,count=1",
     },
 }
 
 
-autoscale_option = click.option(
-    "--autoscale/--no-autoscale",
-    help="Cluster autoscaling",
-    default=True,
-    show_default=True,
-)
-
-
-def nodegroup_args(ng_type, count, pvm=False, **kwargs):
+def nodegroup_args(ng_type, count, pvm=None, autoscale=None, **kwargs):
     count = int(count)
     args = merge_dicts(DEFAULT_NODE_CONFIGS, NODE_POOL_TYPES[ng_type])
     args.update(kwargs)
     if pvm:
         args["preemptible"] = None  # Add as flag
+    if autoscale:
+        args["enable-autoscaling"] = None
     max_nodes = args.get("max-nodes", count)
     args["max-nodes"] = max_nodes if count < max_nodes else count + 1
-    if args.pop("autoscale", True):
-        args["enable-autoscaling"] = None
-    return " ".join([f"--{k}" if v is None else f"--{k}={v}" for k, v in args.items()])
+    return " ".join(
+        sorted([f"--{k}" if v is None else f"--{k}={v}" for k, v in args.items()])
+    )
 
 
 @click.group("gke")
@@ -83,42 +90,85 @@ environment_subnets = {
 }
 
 
-@gke.command("create-nodepools")
+@gke.group("nodepools")
+@click.pass_context
+def gke_nodepools(ctx):
+    """
+    Managing kubernetes cluster's nodepools on Google Kubernetes Engine
+    """
+    pass
+
+
+@gke_nodepools.command("list")
+@click.pass_context
+def list_nodepools(ctx):
+    """
+    Lists the node pool types and default configurations for each
+    """
+    for np, conf in NODE_POOL_TYPES.items():
+        click.secho(f"{np}", fg="green")
+        click.echo("\t" + "\n\t".join(nodegroup_args(np, 1).split(" ")) + "\n")
+
+
+@gke_nodepools.command("create")
 @click.pass_context
 @click.option(
-    "--cluster-name", required=True, help="Name of cluster to attach nodepools to"
+    "-c", "--cluster-name", required=True, help="Name of cluster to attach nodepools to"
 )
 @click.option(
+    "-n",
     "--node-pool",
-    help=f"additional pools and counts. EX: --node-pool gpu=3 --node-pool finetune=1. Types are {list(NODE_POOL_TYPES.keys())}",
+    help=(
+        "Additional pools and counts. Format [name:]type=size. EX: "
+        "-n gpu=3 -n my-pool:cpu=1 makes 'gpu' (gpu) and 'my-pool' (cpu-type) pools. "
+        f"Types are {list(NODE_POOL_TYPES.keys())}"
+    ),
     multiple=True,
 )
-@click.option("--pvm", help=f"enable preemptible nodes", is_flag=True)
-@autoscale_option
+@click.option(
+    "--pvm",
+    help=f"Enable preemptible nodes. PVM-named groups are always preemptible.",
+    is_flag=True,
+)
+@click.option(
+    "--autoscale",
+    help="Enable autoscaling for nodegroup(s). PVM groups are always autoscaled",
+    is_flag=True,
+)
+@click.option(
+    "--dry-run", help=f"Print the create command instead of running", is_flag=True
+)
 def create_nodepools(
-    ctx, cluster_name, autoscale=True, node_pool=None, pvm: bool = False
+    ctx,
+    cluster_name,
+    node_pool=None,
+    autoscale: bool = None,
+    pvm: bool = None,
+    dry_run: bool = None,
 ):
     """
     Creates additional nodepools for existing cluster
     """
-    node_pools = {}
+    node_pools = []
     for np in node_pool or []:
-        np_type, np_size = np.split("=", 1)
+        _type, _size = np.split("=", 1)
+        _name, _type = _type.split(":", 1) if ":" in _type else (_type, _type)
         assert (
-            np_type in NODE_POOL_TYPES
-        ), f"node_pool type {np_type} is not valid. Please select from {NODE_POOL_TYPES}"
+            _type in NODE_POOL_TYPES
+        ), f"node_pool type {_type} is not valid. Options: {NODE_POOL_TYPES}"
         assert (
-            int(np_size) > 0
-        ), f"node_pool size {np_size} is not valid. Please specify an int > 0"
-        node_pools[np_type] = np_size
+            int(_size) > 0
+        ), f"node_pool size {_size} is not valid. Please specify an int > 0"
+        node_pools.append((_name, _type, _size))
 
     if not node_pools:
         return
 
-    for np, count in node_pools.items():
+    cmd_to_run = print if dry_run else run_cmd
+    for name, np, count in node_pools:
         count = int(count)
-        run_cmd(
-            f"gcloud container node-pools create {np}{'-pvm' if pvm else ''} "
+        cmd_to_run(
+            f"gcloud container node-pools create {name}{'-pvm' if pvm else ''} "
             f"--num-nodes={count} --cluster={cluster_name} "
             + nodegroup_args(np, count, pvm)
         )
@@ -136,17 +186,14 @@ def create_nodepools(
 @click.option(
     "--project", help="GKE Project Name", default="new-indico", show_default=True
 )
-@click.option("--zone", help="GKE zone", default="us-east4-c", show_default=True)
-@click.option(
-    "-d",
-    "--deployment-root",
-    default=os.getcwd(),
-    show_default=True,
-    help="Root directory for installation files",
-)
+@click.option("--zone", help="GKE zone", default="us-central1-f", show_default=True)
 @click.option(
     "--node-pool",
-    help=f"additional pools. EX: --node-pool gpu=3 --node-pool finetune=1. Types are {list(NODE_POOL_TYPES.keys())}",
+    help=(
+        f"additional pools (default-pool already included). "
+        "EX: --node-pool gpu=3 --node-pool finetune=1. "
+        f"Types are {list(NODE_POOL_TYPES.keys())}"
+    ),
     multiple=True,
 )
 @click.option(
@@ -155,7 +202,6 @@ def create_nodepools(
     default=True,
     show_default=True,
 )
-@autoscale_option
 def create_cluster(
     ctx,
     environment,
@@ -165,10 +211,8 @@ def create_cluster(
     version=None,
     project=None,
     zone=None,
-    deployment_root=None,
     node_pool=None,
     optimize=True,
-    autoscale=True,
 ):
     """
     Creates a GKE cluster through gcloud.
@@ -182,7 +226,14 @@ def create_cluster(
     The subnetwork specified needs to be created in the network
         created in the zone desired.
 
-    Development scaling is: default-pool=1, default-gpu-pool=1, default-pvm-pool=1
+    Development scaling is:
+        default-pool=2,
+        default-gpu-pool=2,
+        default-pvm-pool=1,
+        default-gpu-pvm-pool=1
+
+    Pools created here will use default configurations.
+    Use the `gke create-nodepool` for additional options.
     """
     environment = next(
         iter(
@@ -200,7 +251,7 @@ def create_cluster(
 
     subnetwork = subnetwork or environment_subnets[environment][zone]
     network = (
-        f"indico-production" if environment is "staging" else f"indico-{environment}"
+        f"indico-production" if environment == "staging" else f"indico-{environment}"
     )
     optimization_profile = "optimize-utilization" if optimize else "balanced"
 
@@ -229,7 +280,7 @@ def create_cluster(
             --subnetwork "{subnetwork}" \
             --autoscaling-profile "{optimization_profile}" \
         """
-        + nodegroup_args("default-pool", size, autoscale=autoscale)
+        + nodegroup_args("default-pool", size)
     )
 
     # TODO: Refactor rbac & switch
@@ -243,14 +294,7 @@ def create_cluster(
         """
     )
 
-    email = run_cmd(
-        f"""
-        cat {deployment_root}/.config/gcloud/configurations/config_default \
-            | grep account \
-            | awk -F "=" '{{print $2}}'
-        """
-    )
-
+    email = current_user()
     user = email.split("@")[0]
 
     run_cmd(
@@ -260,8 +304,8 @@ def create_cluster(
     )
     if node_pool:
         ctx.invoke(
-            create_nodepools,
-            cluster_name=name,
-            node_pool=node_pool,
-            autoscale=autoscale,
+            create_nodepools, cluster_name=name, node_pool=node_pool,
         )
+
+
+gke.add_command(cluster)
