@@ -3,7 +3,11 @@ from pathlib import Path
 
 import click
 
-from indico_install.cluster_manager import ClusterManager, get_services_yaml_from_tag
+from indico_install.cluster_manager import (
+    ClusterManager,
+    get_services_yaml_from_tag,
+    list_backups,
+)
 from indico_install.config import merge_dicts, yaml
 from indico_install.helm.apply import apply
 from indico_install.helm.render import render
@@ -40,22 +44,15 @@ def updraft():
     """Manage deployments and versioning"""
     pass
 
+
 @updraft.command("ls")
 @click.pass_context
 @click.option("-n", "--number", type=int, help="Max number of results")
-@click.option("-o", "--ordered", is_flag=True, help="Order results most to least recent (expensive). Only available if REGEX is provided")
-@click.argument("regex", required=False)
-def list_versions(ctx, number=None, ordered=False, regex=None):
+def list_versions(ctx, number=None):
     """
-    Display available versions of updraft, ordered most to least recent
-
-    Use REGEX to filter the updraft tags.
+    Display available, released versions of updraft, ordered most to least recent
     """
-    if ordered and not regex:
-        click.secho(f"Please provide REGEX to use --ordered")
-        ordered = False
-
-    results = ClusterManager.get_updraft_versions(regex, number, ordered)
+    results = ClusterManager.get_updraft_versions(number)
     click.secho("\n".join(results))
 
 
@@ -132,13 +129,17 @@ def edit_configmap(
         return
     changes = None
     replace = False
+
+    if any([interactive, patch_file, patch]):
+        replace = True
+        cluster_manager.save(backup=True)
+
     service_state = cluster_manager.clean_services()
     if interactive:
         changes = click.edit(
             yaml.dump(cluster_manager.cluster_config, default_flow_style=False)
         )
-        changes = yaml.safe_load(changes) if changes else changes
-        replace = True
+        changes = yaml.safe_load(changes or "")
     elif patch_file:
         changes = json.load(patch_file)
     elif patch:
@@ -147,11 +148,11 @@ def edit_configmap(
     version = string_to_tag(version) if version else None
     if force or changes or (version and version != cluster_manager.indico_version):
         if force or version:
-            click.secho(f"This will override any custom images as well!", fg="yellow")
+            click.secho(f"This will override custom images!", fg="yellow")
         cluster_manager.edit_cluster_config(
             changes=merge_dicts(changes or {}, service_state),
             version=version,
-            replace=replace
+            replace=replace,
         )
     else:
         click.secho(
@@ -159,8 +160,7 @@ def edit_configmap(
         )
         return
 
-    if yes or click.confirm("Render and apply with changes?"):
-        cluster_manager.save(backup=True)
+    if yes or click.confirm("Render with changes?"):
         refresh_cluster_manager(
             ctx,
             cluster_manager,
@@ -172,25 +172,49 @@ def edit_configmap(
 
 @updraft.command("restore")
 @click.pass_context
+@click.option(
+    "--keep-images", is_flag=True, help=f"Keep the current deployed images",
+)
 @options_wrapper()
-def restore_version(ctx, deployment_root, yes):
+def restore_version(ctx, deployment_root, yes, keep_images=False):
     """
-    (Alpha) If an old version of the cluster_manager exists, pull it
-    load the original state, and apply
+    (Alpha) If backups of the cluster_manager exist, choose and restore
+    to a specific backup
     """
-    cluster_manager = ClusterManager()
-    if not cluster_manager.load_from_cluster(backup=True):
+    backups = list_backups()
+    if not backups:
         click.secho("No backup available!", fg="red")
         return
+    backup = click.prompt(
+        (
+            "Backups available\n"
+            + "\n".join(f" [{i}] {v}" for i, v in enumerate(backups))
+            + "\nSelect backup id"
+        ),
+        type=click.Choice(list(str(i) for i in range(len(backups)))),
+        default="0",
+        show_choices=False,
+    )
+    backup = backups[int(backup)]
 
-    cluster_manager.lock()
-    try:
-        if yes or click.confirm("Apply backup?"):
-            refresh_cluster_manager(
-                ctx, cluster_manager, deployment_root, yes, allow_image_overrides=True
-            )
-    finally:
-        cluster_manager.unlock()
+    cluster_manager = ClusterManager()
+    curr_state = None
+    if keep_images:
+        cluster_manager.load_from_cluster()
+        curr_state = cluster_manager.clean_services()
+
+    cluster_manager.load_from_cluster(backup_conf=backup)
+    if keep_images and curr_state:
+        cluster_manager.clean_services()
+        cluster_manager.edit_cluster_config(changes=curr_state)
+
+    click.secho("Please review backup:", fg="green")
+    click.secho(ClusterManager().to_str())
+
+    if yes or click.confirm("Save and apply backup? "):
+        refresh_cluster_manager(
+            ctx, cluster_manager, deployment_root, yes, allow_image_overrides=True
+        )
 
 
 @updraft.command("init")
